@@ -255,188 +255,6 @@ featurePlot <- function(seu, feature=NULL, cols=NULL, pt_size=1, title_size=16,
 
 
 
-ridgePlot <- function (object, features,group.names='Domain' , cols = NULL, idents = NULL, sort = FALSE, 
-                         assay = NULL, group.by = NULL, y.max = NULL, same.y.lims = FALSE, 
-                         log = FALSE, ncol = NULL, slot = "data", stack = FALSE, 
-                         combine = TRUE, fill.by = "feature") {
-  # require(ggplot2)
-  return(ExIPlot(object = object,group.names =group.names, type = "ridge", features = features, 
-                 idents = idents, ncol = ncol, sort = sort, assay = assay, 
-                 y.max = y.max, same.y.lims = same.y.lims, cols = cols, 
-                 group.by = group.by, log = log, slot = slot, stack = stack, 
-                 combine = combine, fill.by = fill.by))
-}
-
-ExIPlot <- function (object, features, group.names='Domain', type = "violin", idents = NULL, 
-                     ncol = NULL, sort = FALSE, assay = NULL, y.max = NULL, same.y.lims = FALSE, 
-                     adjust = 1, cols = NULL, pt.size = 0, group.by = NULL, split.by = NULL, 
-                     log = FALSE, slot = "data", stack = FALSE, combine = TRUE, 
-                     fill.by = NULL, flip = FALSE, raster = NULL, title_size=20) {
-  assay <- assay %||% DefaultAssay(object = object)
-  DefaultAssay(object = object) <- assay
-  if (isTRUE(x = stack)) {
-    if (!is.null(x = ncol)) {
-      warning("'ncol' is ignored with 'stack' is TRUE", 
-              call. = FALSE, immediate. = TRUE)
-    }
-    if (!is.null(x = y.max)) {
-      warning("'y.max' is ignored when 'stack' is TRUE", 
-              call. = FALSE, immediate. = TRUE)
-    }
-  }
-  else {
-    ncol <- ncol %||% ifelse(test = length(x = features) > 
-                               9, yes = 4, no = min(length(x = features), 3))
-  }
-  Interleave <- function (...) 
-  {
-    return(as.vector(x = t(x = as.data.frame(x = list(...)))))
-  }
-  Col2Hex <- function (...) 
-  {
-    colors <- as.character(x = c(...))
-    alpha <- rep.int(x = 255, times = length(x = colors))
-    if (sum(sapply(X = colors, FUN = grepl, pattern = "^#")) != 
-        0) {
-      hex <- colors[which(x = grepl(pattern = "^#", x = colors))]
-      hex.length <- sapply(X = hex, FUN = nchar)
-      if (9 %in% hex.length) {
-        hex.alpha <- hex[which(x = hex.length == 9)]
-        hex.vals <- sapply(X = hex.alpha, FUN = substr, start = 8, 
-                           stop = 9)
-        dec.vals <- sapply(X = hex.vals, FUN = strtoi, base = 16)
-        alpha[match(x = hex[which(x = hex.length == 9)], 
-                    table = colors)] <- dec.vals
-      }
-    }
-    colors <- t(x = col2rgb(col = colors))
-    colors <- mapply(FUN = function(i, alpha) {
-      return(rgb(colors[i, , drop = FALSE], alpha = alpha, 
-                 maxColorValue = 255))
-    }, i = 1:nrow(x = colors), alpha = alpha)
-    return(colors)
-  }
-  
-  
-  
-  data <- FetchData(object = object, vars = features, slot = slot)
-  pt.size <- pt.size %||% AutoPointSize(data = object)
-  features <- colnames(x = data)
-  if (is.null(x = idents)) {
-    cells <- colnames(x = object)
-  }
-  else {
-    cells <- names(x = Idents(object = object)[Idents(object = object) %in% 
-                                                 idents])
-  }
-  data <- data[cells, , drop = FALSE]
-  idents <- if (is.null(x = group.by)) {
-    Idents(object = object)[cells]
-  }
-  else {
-    object[[group.by, drop = TRUE]][cells]
-  }
-  if (!is.factor(x = idents)) {
-    idents <- factor(x = idents)
-  }
-  if (is.null(x = split.by)) {
-    split <- NULL
-  }
-  else {
-    split <- object[[split.by, drop = TRUE]][cells]
-    if (!is.factor(x = split)) {
-      split <- factor(x = split)
-    }
-    if (is.null(x = cols)) {
-      cols <- hue_pal()(length(x = levels(x = idents)))
-      cols <- Interleave(cols, InvertHex(hexadecimal = cols))
-    }
-    else if (length(x = cols) == 1 && cols == "interaction") {
-      split <- interaction(idents, split)
-      cols <- hue_pal()(length(x = levels(x = idents)))
-    }
-    else {
-      cols <- Col2Hex(cols)
-    }
-    if (length(x = cols) < length(x = levels(x = split))) {
-      cols <- Interleave(cols, InvertHex(hexadecimal = cols))
-    }
-    cols <- rep_len(x = cols, length.out = length(x = levels(x = split)))
-    names(x = cols) <- levels(x = split)
-    if ((length(x = cols) > 2) & (type == "splitViolin")) {
-      warning("Split violin is only supported for <3 groups, using multi-violin.")
-      type <- "violin"
-    }
-  }
-  if (same.y.lims && is.null(x = y.max)) {
-    y.max <- max(data)
-  }
-  if (isTRUE(x = stack)) {
-    return(MultiExIPlot(type = type, data = data, idents = idents, 
-                        split = split, sort = sort, same.y.lims = same.y.lims, 
-                        adjust = adjust, cols = cols, pt.size = pt.size, 
-                        log = log, fill.by = fill.by, flip = flip))
-  }
-  if(type =='ridge'){
-    plots <- lapply(X = features, FUN = function(x) {
-      return(SingleExIPlot(type = type, data = data[, x, drop = FALSE], 
-                           idents = idents, split = split, sort = sort, y.max = y.max, 
-                           adjust = adjust, cols = cols, pt.size = pt.size, 
-                           log = log, raster = raster)+ ggplot2::ylab(group.names))
-    })
-  }else{
-    plots <- lapply(X = features, FUN = function(x) {
-      return(SingleExIPlot(type = type, data = data[, x, drop = FALSE], 
-                           idents = idents, split = split, sort = sort, y.max = y.max, 
-                           adjust = adjust, cols = cols, pt.size = pt.size, 
-                           log = log, raster = raster) + ggplot2::ylab(group.names))
-    })
-  }
-  
-  label.fxn <- switch(EXPR = type, violin = if (stack) {
-    xlab
-  } else {
-    ylab
-  }, splitViolin = if (stack) {
-    xlab
-  } else {
-    ylab
-  }, ridge = xlab, stop("Unknown ExIPlot type ", type, 
-                        call. = FALSE))
-  for (i in 1:length(x = plots)) {
-    key <- paste0(unlist(x = strsplit(x = features[i], split = "_"))[1], 
-                  "_")
-    obj <- names(x = which(x = Key(object = object) == key))
-    if (length(x = obj) == 1) {
-      if (inherits(x = object[[obj]], what = "DimReduc")) {
-        plots[[i]] <- plots[[i]] + label.fxn(label = "Embeddings Value")
-      }
-      else if (inherits(x = object[[obj]], what = "Assay")) {
-        next
-      }
-      else {
-        warning("Unknown object type ", class(x = object), 
-                immediate. = TRUE, call. = FALSE)
-        plots[[i]] <- plots[[i]] + label.fxn(label = NULL)
-      }
-    }
-    else if (!features[i] %in% rownames(x = object)) {
-      plots[[i]] <- plots[[i]] + label.fxn(label = NULL)
-    }
-  }
-  for (i in 1:length(x = plots)) {
-    plots[[i]] <- plots[[i]] +  ggplot2::ylab(group.names)
-  }
-  
-  if (combine) {
-    plots <- patchwork::wrap_plots(plots, ncol = ncol)
-    if (length(x = features) > 1) {
-      plots <- plots & NoLegend()
-    }
-  }
-  return(plots)
-}
-
 # Plot  Theme -------------------------------------------------------------------
 
 
